@@ -37,6 +37,7 @@ from flask import request
 from flask.views import MethodView
 from sqlalchemy import Date
 from sqlalchemy import DateTime
+from sqlalchemy.exc import IntegrityError
 from sqlalchemy.exc import OperationalError
 from sqlalchemy.orm import class_mapper
 from sqlalchemy.orm import ColumnProperty
@@ -454,8 +455,7 @@ class ModelView(MethodView):
         class.
 
         """
-        the_model = model or self.model
-        return session_query(self.session, the_model)
+        return session_query(self.session, model or self.model)
 
 
 class FunctionAPI(ModelView):
@@ -1134,7 +1134,7 @@ class API(ModelView):
             for postprocessor in self.postprocessors['GET_SINGLE']:
                 result = postprocessor(result)
             return jsonpify(result)
-        except ProcessingException as e:
+        except ProcessingException, e:
             return jsonify_status_code(status_code=e.status_code,
                                        message=e.message)
 
@@ -1152,7 +1152,7 @@ class API(ModelView):
         try:
             for preprocessor in self.preprocessors['DELETE']:
                 preprocessor(instid)
-        except ProcessingException as e:
+        except ProcessingException, e:
             return jsonify_status_code(status_code=e.status_code,
                                        message=e.message)
 
@@ -1164,7 +1164,7 @@ class API(ModelView):
         try:
             for postprocessor in self.postprocessors['DELETE']:
                 postprocessor(is_deleted)
-        except ProcessingException as e:
+        except ProcessingException, e:
             return jsonify_status_code(status_code=e.status_code,
                                        message=e.message)
 
@@ -1207,7 +1207,7 @@ class API(ModelView):
         try:
             for preprocessor in self.preprocessors['POST']:
                 params = preprocessor(params)
-        except ProcessingException as e:
+        except ProcessingException, e:
             return jsonify_status_code(status_code=e.status_code,
                                        message=e.message)
 
@@ -1258,13 +1258,15 @@ class API(ModelView):
             try:
                 for postprocessor in self.postprocessors['POST']:
                     result = postprocessor(result)
-            except ProcessingException as e:
+            except ProcessingException, e:
                 return jsonify_status_code(status_code=e.status_code,
                                            message=e.message)
 
             return jsonify_status_code(201, **result)
         except self.validation_exceptions, exception:
             return self._handle_validation_exception(exception)
+        except IntegrityError, error:
+            return jsonify_status_code(400, message=error.message)
 
     def patch(self, instid):
         """Updates the instance specified by ``instid`` of the named model, or
@@ -1307,7 +1309,7 @@ class API(ModelView):
                     search_params, data = preprocessor(search_params, data)
                 # create a SQLALchemy Query from the query parameter `q`
                 query = create_query(self.session, self.model, search_params)
-            except ProcessingException as e:
+            except ProcessingException, e:
                 return jsonify_status_code(status_code=e.status_code,
                                            message=e.message)
             except:
@@ -1317,7 +1319,7 @@ class API(ModelView):
             try:
                 for preprocessor in self.preprocessors['PATCH_SINGLE']:
                     data = preprocessor(instid, data)
-            except ProcessingException as e:
+            except ProcessingException, e:
                 return jsonify_status_code(status_code=e.status_code,
                                            message=e.message)
             # create a SQLAlchemy Query which has exactly the specified row
@@ -1351,7 +1353,7 @@ class API(ModelView):
             try:
                 for postprocessor in self.postprocessors['PATCH_MANY']:
                     result = postprocessor(query, result)
-            except ProcessingException as e:
+            except ProcessingException, e:
                 return jsonify_status_code(status_code=e.status_code,
                                            message=e.message)
         else:
@@ -1359,7 +1361,7 @@ class API(ModelView):
             try:
                 for postprocessor in self.postprocessors['PATCH_SINGLE']:
                     result = postprocessor(result)
-            except ProcessingException as e:
+            except ProcessingException, e:
                 return jsonify_status_code(status_code=e.status_code,
                                            message=e.message)
 
